@@ -16,12 +16,14 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains SFTP sensor."""
+from datetime import datetime
 from typing import TYPE_CHECKING, Optional, Sequence
 
 from paramiko.sftp import SFTP_NO_SUCH_FILE
 
 from airflow.providers.sftp.hooks.sftp import SFTPHook
 from airflow.sensors.base import BaseSensorOperator
+from airflow.utils.timezone import convert_to_utc
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
@@ -33,15 +35,27 @@ class SFTPSensor(BaseSensorOperator):
 
     :param path: Remote file or directory path
     :param sftp_conn_id: The connection to run the sensor against
+    :param newer_than: DateTime for which the file or file path should be newer than, comparison is inclusive
     """
 
-    template_fields: Sequence[str] = ('path',)
+    template_fields: Sequence[str] = (
+        'path',
+        'newer_than',
+    )
 
-    def __init__(self, *, path: str, sftp_conn_id: str = 'sftp_default', **kwargs) -> None:
+    def __init__(
+        self,
+        *,
+        path: str,
+        newer_than: Optional[datetime] = None,
+        sftp_conn_id: str = 'sftp_default',
+        **kwargs,
+    ) -> None:
         super().__init__(**kwargs)
         self.path = path
         self.hook: Optional[SFTPHook] = None
         self.sftp_conn_id = sftp_conn_id
+        self.newer_than: Optional[datetime] = newer_than
 
     def poke(self, context: 'Context') -> bool:
         self.hook = SFTPHook(self.sftp_conn_id)
@@ -54,4 +68,9 @@ class SFTPSensor(BaseSensorOperator):
                 raise e
             return False
         self.hook.close_conn()
-        return True
+        if self.newer_than:
+            _mod_time = convert_to_utc(datetime.strptime(mod_time, '%Y%m%d%H%M%S'))
+            _newer_than = convert_to_utc(self.newer_than)
+            return _newer_than <= _mod_time
+        else:
+            return True
